==> ada-cli-1.1.0.tgz: package/texts.js <==
'use strict'

const config = require('./config.json')
const conf = config[process.env.NODE_ENV || 'dev']

const _ = require('lodash')
const async = require('async')

const ada = require('./lib/index.js')
const store = require('./lib/store.js')

const twilio = require('twilio')
const twilioClient = twilio(conf.twilio.accountSid, conf.twilio.authToken)

const express = require('express')
const bodyParser = require('body-parser')
const app = express()

// for debugging:
// const readline = require('readline')
// const rl = readline.createInterface({
//   input: process.stdin,
//   output: process.stdout
// })

app.use(bodyParser.urlencoded({ extended: false }))
app.listen(conf.server.port)

app.post('/', (request, response) => {
  console.log(request.body.From)
  console.log(request.body.Body)
  mapResponseToAnswer(request.body.Body, request.body.From)
})

const sendResult = (result) => {
  const message = [`${result.advice}, ${result.heading}`]

  result.conditions.map((condition) => {
    message.push(`${condition.estimation}: ${condition.name}`)
  })

  sendText(message.join('\n'), () => {
    console.log('done 🎉')
  })
}

const mapResponseToAnswer = (response, telephoneNumber) => {
  store.getState(telephoneNumber, (err, state) => {
    if (!state) return ask(telephoneNumber)

    if (err) throw err

    if (state.advice) return sendResult(state)
    if (state.answerType === 'TEXT') return ask(telephoneNumber, response)

    response = response.replace(/[^0-9]+/gi, '')
    const highestResponse = state.answerOptions.length
    if (response > highestResponse || !response.length) {
      const warn = `Please enter a number from 1 - ${highestResponse}. Thanks <3 ️`
      return sendText(telephoneNumber, warn, () => {})
    }
    return ask(telephoneNumber, state.answerOptions[response - 1])
  })
}

const ask = (telephoneNumber, answerObj) => {
  ada(telephoneNumber, answerObj, (question) => {
    const send = []
    send.push(_.flattenDeep([].concat(question.question)).join(' '))

    if (question.answerType === 'SELECT') {
      send.push(question.answerOptions.map((answer, index) => {
        return `${++index}. ${answer.text || answer.patientName}`
      }).join('\n'))
    }

    async.eachSeries(send, sendText.bind(undefined, telephoneNumber), (err) => {
      if (err) console.error(err)
    })
  })
}

const sendText = (number, message, cb) => {
  console.log(number, message)
  twilioClient.sendMessage({
    to: number,
    from: conf.twilio.from,
    body: message
  }, (err, responseData) => {
    if (err) cb(err)
    console.log('Message ', responseData.status)
    cb()
  })
}

==> ada-cli-1.2.6.tgz: package/texts.js <==
'use strict'

const config = require('./lib/rc')().get()

const _ = require('lodash')
const async = require('async')

const ada = require('./lib/index.js')
const store = require('./lib/store.js')

const twilio = require('twilio')
const twilioClient = twilio(config.twilio.accountSid, config.twilio.authToken)

const express = require('express')
const bodyParser = require('body-parser')
const app = express()

// for debugging:
// const readline = require('readline')
// const rl = readline.createInterface({
//   input: process.stdin,
//   output: process.stdout
// })

app.use(bodyParser.urlencoded({ extended: false }))
app.listen(config.server.port)

app.post('/', (request, response) => {
  console.log(request.body.From)
  console.log(request.body.Body)
  mapResponseToAnswer(request.body.Body, request.body.From)
})

const sendResult = (result) => {
  const message = [`${result.advice}, ${result.heading}`]

  result.conditions.map((condition) => {
    message.push(`${condition.estimation}: ${condition.name}`)
  })

  sendText(message.join('\n'), () => {
    console.log('done 🎉')
  })
}

const mapResponseToAnswer = (response, telephoneNumber) => {
  store.getState(telephoneNumber, (err, state) => {
    if (!state) return ask(telephoneNumber)

    if (err) throw err

    if (state.advice) return sendResult(state)
    if (state.answerType === 'TEXT') return ask(telephoneNumber, response)

    response = response.replace(/[^0-9]+/gi, '')
    const highestResponse = state.answerOptions.length
    if (response > highestResponse || !response.length) {
      const warn = `Please enter a number from 1 - ${highestResponse}. Thanks <3 ️`
      return sendText(telephoneNumber, warn, () => {})
    }
    return ask(telephoneNumber, state.answerOptions[response - 1])
  })
}

const ask = (telephoneNumber, answerObj) => {
  ada(telephoneNumber, answerObj, (question) => {
    const send = []
    send.push(_.flattenDeep([].concat(question.question)).join(' '))

    if (question.answerType === 'SELECT') {
      send.push(question.answerOptions.map((answer, index) => {
        return `${++index}. ${answer.text || answer.patientName}`
      }).join('\n'))
    }

    async.eachSeries(send, sendText.bind(undefined, telephoneNumber), (err) => {
      if (err) console.error(err)
    })
  })
}

const sendText = (number, message, cb) => {
  console.log(number, message)
  twilioClient.sendMessage({
    to: number,
    from: config.twilio.from,
    body: message
  }, (err, responseData) => {
    if (err) cb(err)
    console.log('Message ', responseData.status)
    cb()
  })
}
